@@ -22,30 +22,30 @@ from flask import session, redirect, url_for
 
 FIELDS = (
     'sAMAccountName',
-    'distinguishedName', # 'ad_cn',
+    'distinguishedName',  # 'ad_cn',
 
-    'givenName', # 'first_name'
-    'sn', # 'last_name',
-    'middleName', # 'middle_name',
-    'description', # 'full_name',
+    'givenName',  # 'first_name'
+    'sn',  # 'last_name',
+    'middleName',  # 'middle_name',
+    'description',  # 'full_name',
 
-    'company', # 'company',
-    'department', # 'department',
-    'title', # 'title',
-    'manager', # 'manager',
+    'company',  # 'company',
+    'department',  # 'department',
+    'title',  # 'title',
+    'manager',  # 'manager',
 
-    'cn', # 'name_lat',
-    'name', # 'name_lat',
-    'displayName', # 'display_name',
+    'cn',  # 'name_lat',
+    'name',  # 'name_lat',
+    'displayName',  # 'display_name',
     'displayNamePrintable',
 
     # 'comment',            # 'gender',
-    'primaryTelexNumber', # 'birth_date',  # дата рождения
+    'primaryTelexNumber',  # 'birth_date',  # дата рождения
 
-    'employeeID', # 'employee_id',
-    'mail', # 'mail',
-    'mobile', # 'mobile',
-    'streetAddress', # 'location',
+    'employeeID',  # 'employee_id',
+    'mail',  # 'mail',
+    'mobile',  # 'mobile',
+    'streetAddress',  # 'location',
     'ipPhone',
 )
 
@@ -112,7 +112,11 @@ class LDAP(object):
         try:
             self.connect()
             user = "{0}@{1}".format(username, self.app.config['LDAP_DOMAIN'])
-            self.conn.simple_bind_s(user, pwd.encode('utf8'))
+            try:
+                self.conn.simple_bind_s(user, pwd.encode('utf8'))
+            except ldap.SERVER_DOWN as e:
+                flash(message=dict(e.message)['desc'], category='error')
+                return False
             query = "sAMAccountName=%s" % username
             session['username'] = username
             for user in self.ldap_query(query):
@@ -146,7 +150,8 @@ class LDAP(object):
 
             return True
 
-        except ldap.INVALID_CREDENTIALS:
+        except ldap.INVALID_CREDENTIALS as e:
+            flash(message=dict(e.message)['desc'], category='error')
             return False
 
     def login(self):
